==> owncloud-9.0.3.tgz: owncloud/settings/ajax/uninstallapp.php <==
<?php
/**
 * @author Georg Ehrke <georg@owncloud.com>
 * @author Lukas Reschke <lukas@owncloud.com>
 * @author Robin Appelman <icewind@owncloud.com>
 *
 * @copyright Copyright (c) 2016, ownCloud, Inc.
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License, version 3,
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 *
 */
OCP\JSON::checkAdminUser();
OCP\JSON::callCheck();

if (!array_key_exists('appid', $_POST)) {
	OC_JSON::error();
	exit;
}

$appId = (string)$_POST['appid'];
$appId = OC_App::cleanAppId($appId);

$result = OC_App::removeApp($appId);
if($result !== false) {
	// FIXME: Clear the cache - move that into some sane helper method
	\OC::$server->getMemCacheFactory()->create('settings')->remove('listApps-0');
	\OC::$server->getMemCacheFactory()->create('settings')->remove('listApps-1');
	OC_JSON::success(array('data' => array('appid' => $appId)));
} else {
	$l = \OC::$server->getL10N('settings');
	OC_JSON::error(array("data" => array( "message" => $l->t("Couldn't remove app.") )));
}

==> owncloud-10.0.7.tgz: owncloud/settings/ajax/uninstallapp.php <==
<?php
/**
 * @author Georg Ehrke <georg@owncloud.com>
 * @author Lukas Reschke <lukas@statuscode.ch>
 * @author Robin Appelman <icewind@owncloud.com>
 * @author Thomas Müller <thomas.mueller@tmit.eu>
 *
 * @copyright Copyright (c) 2017, ownCloud GmbH
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License, version 3,
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 *
 */
OCP\JSON::checkAdminUser();
OCP\JSON::callCheck();

if (!array_key_exists('appid', $_POST)) {
	OC_JSON::error();
	exit;
}

$appId = (string)$_POST['appid'];
$appId = OC_App::cleanAppId($appId);

$result = OC_App::removeApp($appId);
if($result !== false) {
	// FIXME: Clear the cache - move that into some sane helper method
	\OC::$server->getMemCacheFactory()->create('settings')->remove('listApps-0');
	\OC::$server->getMemCacheFactory()->create('settings')->remove('listApps-1');
	OC_JSON::success(['data' => ['appid' => $appId]]);
} else {
	$l = \OC::$server->getL10N('settings');
	OC_JSON::error(["data" => ["message" => $l->t("Couldn't remove app.")]]);
}
